unit Header;

interface

uses
  SysUtils, WinTypes, WinProcs, Classes;

type
  { Enter 'Delay': off, as checkbox or as edit field }
  TDelayed = (dOff, dCheck, dEdit);

  { Enum for labels (CKeys and CLabelValues) }
  KeyIndexes = (
    KIQueryFrom, KIWaiting, KIOptions,
    KIClose, KIAbout, KIPhoneBook,
    KIReceiver, KIFaxNums, KIRecvName,
    KISender, KIUser, KISendName, KIAlias,
    KIOK, KICancel, KIPort, KILabels, KILoadNetAPI, KISaveHist,
    KIHistory, KIQuerySave,
    KIDelayed, KIdOff, KIdCheck, KIdEdit
  );

const
  KIFirst = KIQueryFrom;       { First element of KeyIndexes }
  KILast = KIdEdit;            { Last element of KeyIndexes  }

  CProgName = 'Respond';       { Program name }
  CProgVersion = '1.5';        { Version      }

  { INI file names }
  { Respond.ini for aliases and history }
  IniFile : array[0..255]of Char = CProgName + '.ini';
  IniName: PChar = @IniFile;
  { Win.ini for options }
  WinIniFile: Array[0..255]of Char = 'WIN.INI';
  WinIni: PChar = @WinIniFile;
  { ini file for labels, regularly Win.ini }
  LabelIni: PChar = @WinIniFile;

  { Menuitems for system menu or trayicon popup menu }
{$IFDEF RESPOND95}
  CloseMenuItemString : array[0..255]of Char = '';
  CloseMenuItem : PChar = @CloseMenuItemString;
{$ENDIF}
  AboutMenuItemString : array[0..255]of Char = '';
  AboutMenuItem : PChar = @AboutMenuItemString;
  PBookMenuItemString : array[0..255]of Char = '';
  PBookMenuItem : PChar = @PBookMenuItemString;

{$IFDEF RESPOND95}
  { Registry entry for user name }
  UserNameKey: PChar = 'Network\Logon';
  UserNameValue: PChar = 'username';
{$ENDIF}

  { WIN.INI entries: }
  { Section names }
  OptionsSection : PChar = CProgName;
  LabelsSection : PChar = CProgName+'-Labels';
  { Key names }
  PortValueKey : PChar = 'Port';
  DelayedKey : PChar = 'Delayed';
  LoadNetAPIKey: PChar = 'LoadNetAPI';
  SaveHistoryKey: PChar = 'SaveHistory';
  MaxHistKey: PChar = 'MaxHistory';
  QueryReceiverNameKey: PChar = 'QueryReceiverName';
  QueryUserKey: PChar = 'QueryUser';
  QuerySenderNameKey: PChar = 'QuerySenderName';

  { Respond.ini entries: }
  AliasSection : PChar = 'Aliases';
  HistorySection : PChar = 'History';

  KMaxHistory = 10;
  KGetMem = 2048;

  KeyCount = Ord(KILast)-Ord(KIFirst)+1;       { Label key count }

  { CKeys covers the label keys from WIN.INI }
  CKeys : array[KeyIndexes]of PChar = (
    'QueryFrom',
    'Waiting',
    'Options',
    'Close',
    'About',
    'PhoneBook',
    'Receiver',
    'Faxnumbers',
    'ReceiverName',
    'Sender',
    'User',
    'SenderName',
    'Alias',
    'OK',
    'Cancel',
    'Port',
    'Labels',
    'LoadNetAPI',
    'SaveHistory',
    'History',
    'QuerySave',
    'Delayed',
    'DelayedOff',
    'DelayedCheck',
    'DelayedEdit'
  );

  { CLabelValues covers the label names from WIN.INI }
  CLabelValues : array[KeyIndexes]of PChar = (
    'Query from',
    'Waiting',
    '&Options',
    '&Close',
    '&About',
    '&Phonebook',
    'Receiver',
    '&Fax-Number(s)',
    '&Name',
    'Sender',
    '&User',
    'N&ame',
    'A&lias',
    '&OK',
    '&Cancel',
    '&Port',
    '&Labels',
    'Load N&ETAPI.DLL',
    'Save &History',
    'History',
    'Save changed values?',
    '&Delayed Send',
    'Off',
    'Checkbox',
    'Editfield'
  );

function UnShortCut( const s: String ): String;
function GetLabelStr(const KI: KeyIndexes): String;
procedure GetLabelPChar(const KI: KeyIndexes; p: PChar; l: Integer);

implementation

function UnShortCut( const s: String ): String;
{ Remove Shortcut-'&' from String }
var
  i: Integer;
begin
  result := s;
  i := Pos( '&', result );
  if i > 0 then Delete( result, i, 1 );
end;

function GetLabelStr(const KI: KeyIndexes): String;
{ Read label from INI file as String }
var
  p : array[0..255]of Char;
begin
  GetLabelPChar(KI, @p, 255);
  Result := StrPas( @p );
end;

procedure GetLabelPChar(const KI: KeyIndexes; p: PChar; l: Integer);
{ Read label from INI file as PChar }
begin
  GetPrivateProfileString( LabelsSection, CKeys[KI], CLabelValues[KI],
                           p, l, LabelIni );
end;

end.
