unit Options;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, Buttons, Grids, Header;

type
  TOptForm = class(TForm)
    PortLabel: TLabel;
    Port: TEdit;
    OKBtn: TBitBtn;
    CancelBtn: TBitBtn;
    Words: TStringGrid;
    LabelsLabel: TLabel;
    DelayedLabel: TLabel;
    DelayedList: TComboBox;
    LoadNetapi: TCheckBox;
    CBSaveHist: TCheckBox;
    CBQueryReceiver: TCheckBox;
    CBQueryUser: TCheckBox;
    CBQuerySender: TCheckBox;
    procedure PortKeyPress(Sender: TObject; var Key: Char);
    procedure WordsKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure WordsClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure OKBtnClick(Sender: TObject);
    procedure CancelBtnClick(Sender: TObject);
    procedure FormCloseQuery(Sender: TObject; var CanClose: Boolean);
  private
    { Private-Deklarationen }
    SavedText : String;
    OKClicked: Boolean;
    procedure WriteValues;
    procedure WriteLabels;
  public
    { Public-Deklarationen }
  end;

var
  OptForm: TOptForm;

implementation

var
  SavedPort: String[5];
  SavedDelayed: Integer;
  SavedLoadNetAPI, SavedSaveHist, SavedQueryReceiver,
  SavedQueryUser, SavedQuerySender: Boolean;
  SavedLabels: Array[KeyIndexes]of String;

{$R *.DFM}

function UnColon(const s: String): String;
{ Remove ':' at the end of a string }
begin
  if s[Length(s)] = ':' then
    Result := Copy(s, 1, Length(s)-1)
  else Result := s;
end;

procedure TOptForm.PortKeyPress(Sender: TObject; var Key: Char);
{ Let user only type digits for the port }
begin
  if ( Key >= #30 ) and ( Key <= #255 ) then
   if ( Key < '0' ) or ( Key > '9' ) then Key := #0;
end;

procedure TOptForm.WordsKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
{ Key processing for label list }
begin
  if Shift = [] then with Words do case Key of
  VK_ESCAPE: Cells[1,Row] := SavedText;     { Restore old value }
  VK_HOME, VK_END, VK_LEFT, VK_RIGHT: begin
      EditorMode := True;
    end;
  end;
end;

procedure TOptForm.WordsClick(Sender: TObject);
{ Save value on enter a cell to allow restoring with ESC }
begin
  SavedText := Words.Cells[1,Words.Row];
end;

procedure TOptForm.FormCreate(Sender: TObject);
var
  s: String;
  i: Integer;
  j: KeyIndexes;
begin
  { Allow private ini files on command line }
  for i := 1 to ParamCount do begin
    s := ParamStr(i);
    if (s = '-l') or (s = '/l') then LabelIni := @IniFile
    else if (s = '-p') or (s = '/p') then begin
      WinIni := @IniFile;
      LabelIni := @IniFile;
    end else begin
      if s[Length(s)] <> '\' then AppendStr(s, '\');
      StrPCopy(@IniFile, s+CProgName+'.ini');
    end;
  end;
  { Set labels from ini file }
  OKBtn.Caption := GetLabelStr(KIOK);
  CancelBtn.Caption := GetLabelStr(KICancel);
  PortLabel.Caption := GetLabelStr(KIPort);
  DelayedLabel.Caption := GetLabelStr(KIDelayed);
  LoadNetapi.Caption := GetLabelStr(KILoadNetAPI);
  CBSaveHist.Caption := GetLabelStr(KISAveHist);
  LabelsLabel.Caption := GetLabelStr(KILabels);
  CBQueryReceiver.Caption :=
    GetLabelStr(KIReceiver)+' - '+UnColon(GetLabelStr(KIRecvName));
  CBQueryUser.Caption :=
    GetLabelStr(KISender)+' - '+UnColon(GetLabelStr(KIUser));
  CBQuerySender.Caption :=
    GetLabelStr(KISender)+' - '+UnColon(GetLabelStr(KISendName));
  Caption := CProgName+' '+UnShortCut(GetLabelStr(KIOptions));
  { Possibilities for delayed sending }
  DelayedList.Clear;
  for j := KIdOff to KIdEdit do
    DelayedList.Items.Add( GetLabelStr(j) );
  DelayedList.Itemindex :=
    Abs(GetPrivateProfileInt( OptionsSection, DelayedKey, 0, WinIni )) mod 3;
  { Label list }
  Words.RowCount := KeyCount;
  for j := KIFirst to KILast do begin
    s := GetLabelStr(j);
    Words.Cells[0,Ord(j)] := StrPas(CKeys[j]);
    Words.Cells[1,Ord(j)] := s;
  end;
  { Other options }
  Port.Text :=
    IntToStr( GetPrivateProfileInt( OptionsSection, PortValueKey, 5555, WinIni ));
  LoadNetapi.Checked :=
    GetPrivateProfileInt( OptionsSection, LoadNetAPIKey, 0, WinIni ) <> 0;
  CBQueryReceiver.Checked :=
    GetPrivateProfileInt( OptionsSection, QueryReceiverNameKey, 1, WinIni ) <> 0;
  CBQueryUser.Checked :=
    GetPrivateProfileInt( OptionsSection, QueryUserKey, 1, WinIni ) <> 0;
  CBQuerySender.Checked :=
    GetPrivateProfileInt( OptionsSection, QuerySenderNameKey, 1, WinIni ) <> 0;
  CBSaveHist.Checked :=
    GetPrivateProfileInt( OptionsSection, SaveHistoryKey, 1, WinIni ) <> 0;
  { Save current values for dirty check }
  SavedPort := Port.Text;
  SavedDelayed := DelayedList.ItemIndex;
  SavedLoadNetAPI := LoadNetapi.Checked;
  SavedQueryReceiver := CBQueryReceiver.Checked;
  SavedQueryUser := CBQueryUser.Checked;
  SavedQuerySender :=CBQuerySender.Checked;
  SavedSaveHist := CBSaveHist.Checked;
  for j := KIFirst to KILast do begin
    SavedLabels[j] := Words.Cells[1,Ord(j)];
  end;
  OKClicked := False;
end;

procedure TOptForm.WriteValues;
{ Write option values to ini file }
var
  p: Array[0..255]of Char;
begin
  { Wenn OK gedrckt, nderungen in WIN.INI speichern: }
  WritePrivateProfileString( OptionsSection, PortValueKey,
    StrPCopy( @p, Port.Text), WinIni );
  WritePrivateProfileString( OptionsSection, DelayedKey,
    StrPCopy( @p, IntToStr( DelayedList.ItemIndex )), WinIni );
  if LoadNetapi.Checked then
    WritePrivateProfileString( OptionsSection, LoadNetAPIKey, '1', WinIni )
  else
    WritePrivateProfileString( OptionsSection, LoadNetAPIKey, '0', WinIni );
  if CBQueryReceiver.Checked then
    WritePrivateProfileString( OptionsSection, QueryReceiverNameKey, '1', WinIni )
  else
    WritePrivateProfileString( OptionsSection, QueryReceiverNameKey, '0', WinIni );
  if CBQueryUser.Checked then
    WritePrivateProfileString( OptionsSection, QueryUserKey, '1', WinIni )
  else
    WritePrivateProfileString( OptionsSection, QueryUserKey, '0', WinIni );
  if CBQuerySender.Checked then
    WritePrivateProfileString( OptionsSection, QuerySenderNameKey, '1', WinIni )
  else
    WritePrivateProfileString( OptionsSection, QuerySenderNameKey, '0', WinIni );
  if CBSaveHist.Checked then
    WritePrivateProfileString( OptionsSection, SaveHistoryKey, '1', WinIni )
  else
    WritePrivateProfileString( OptionsSection, SaveHistoryKey, '0', WinIni );
  { Flush WIN.INI }
  WritePrivateProfileString( nil, nil, nil, WinIni );
end;

procedure TOptForm.WriteLabels;
{ Write label values to ini file }
var
  j: KeyIndexes;
  p: Array[0..255]of Char;
begin
  for j := KIFirst to KILast do begin
    StrPCopy( @p, Words.Cells[1,Ord(j)]);
    if StrComp(CLabelValues[j], @p) <> 0 then
      WritePrivateProfileString( LabelsSection, CKeys[j], @p, LabelIni )
    else
      { Remove keys for default values }
      WritePrivateProfileString( LabelsSection, CKeys[j], nil, LabelIni );
  end;
  { Flush label ini file }
  WritePrivateProfileString( nil, nil, nil, LabelIni );
end;

procedure TOptForm.OKBtnClick(Sender: TObject);
begin
  OKClicked := True;
  Close;
end;

procedure TOptForm.CancelBtnClick(Sender: TObject);
begin
  Close;
end;

procedure TOptForm.FormCloseQuery(Sender: TObject; var CanClose: Boolean);
var
  vdirty, ldirty: Boolean;
  j: KeyIndexes;
  i: Word;
  p: Array[0..255]of Char;
begin
  CanClose := True;
  vdirty := False;
  ldirty := False;
  { Check for option changes }
  if (SavedPort <> Port.Text) or
     (SavedDelayed <> DelayedList.ItemIndex) or
     (SavedLoadNetAPI <> LoadNetapi.Checked) or
     (SavedQueryReceiver <> CBQueryReceiver.Checked) or
     (SavedQueryUser <> CBQueryUser.Checked) or
     (SavedQuerySender <> CBQuerySender.Checked) or
     (SavedSaveHist <> CBSaveHist.Checked) then vdirty := True;
  { Check for label changes }
  for j := KIFirst to KILast do
    if SavedLabels[j] <> Words.Cells[1,Ord(j)] then begin
      ldirty := True;
      break;
    end;
  i := IDNO;
  if (not OKClicked) and (vdirty or ldirty) then begin
    GetLabelPChar(KIQuerySave, @p, 255);
    i := Application.MessageBox(@p, 'Config', MB_YESNOCANCEL
                                           or MB_ICONQUESTION
{$IFDEF RESPOND95}
                                           or MB_RTLREADING
{$ENDIF}
                                              );
  end;
  if i = IDCANCEL then CanClose := False
  else if (OKClicked) or (i = IDYES) then begin
    if vdirty then WriteValues;
    if ldirty then WriteLabels;
  end;
end;

end.
